@@ -9,7 +9,7 @@ use Parallel::ForkManager;
 use Plack::Request;
 use WWW::Mechanize;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 has 'verify_hostname' => (is => 'rw', isa => 'Int', default => 1);
 has 'skip_undef_result' => (is => 'rw', isa => 'Int', default => 1);
@@ -179,7 +179,7 @@ sub worker {
 	print "Path: $path\nPort: $port\n";
 	my $app = $self->load_worker_plack_app($path);
 	my $handler = Plack::Handler::Starlet->new(
-	    max_worker => $worker,
+	    max_workers => $worker,
 	    port => $port
 	   );
 	$handler->run($app);
